@@ -12,3 +12,7 @@ extern gchar *GdmSuspend;
 extern gchar *GdmConfigurator;
 extern gchar *GdmSessionDir;
 extern gchar *GdmDefaultLocale;
+extern gchar *GdmLocaleFile;
+extern gboolean GdmTimedLoginEnable;
+extern gchar *GdmTimedLogin;
+extern gint GdmTimedLoginDelay;
