@@ -1,3 +1,6 @@
+#include "config.h"
+
+#include <libgnome/libgnome.h>
 #include <gtk/gtk.h>
 #include <string.h>
 #include <stdlib.h>
@@ -6,10 +9,9 @@
 
 #include "greeter_item.h"
 #include "greeter_configuration.h"
+#include "vicious.h"
 
-#ifndef _
-#define _(x) (x)
-#endif
+extern gint greeter_current_delay;
 
 GreeterItemInfo *
 greeter_item_info_new (GreeterItemInfo *parent,
@@ -90,15 +92,7 @@ get_clock (void)
   time (&the_time);
   the_tm = localtime (&the_time);
 
-  if (strftime (str, sizeof (str)-1, _("%a %b %d, %I:%M %p"), the_tm) == 0) {
-    /* according to docs, if the string does not fit, the
-     * contents of str are undefined, thus just use
-     * ??? */
-    strcpy (str, "???");
-  }
-  str [sizeof (str)-1] = '\0'; /* just for sanity */
-
-  return g_locale_to_utf8 (str, -1, NULL, NULL, NULL);
+  return ve_strftime (the_tm, _("%a %b %d, %I:%M %p"));
 }
 
 
@@ -133,13 +127,20 @@ greeter_item_expand_text (const char *text)
 	      else
 		g_string_append (str, buf);
 	      break;
-	    case 'd':
+	    case 'o':
 	      r = getdomainname (buf, sizeof(buf));
 	      if (r)
 		g_string_append (str, "localdomain");
 	      else
 		g_string_append (str, buf);
 	      break;
+	    case 'd':
+	      g_string_append_printf (str, "%d",
+				      greeter_current_delay);
+	      break;
+	    case 's':
+	      g_string_append (str, ve_sure_string (GdmTimedLogin));
+	      break;
 	    case 'c':
 	      clock = get_clock ();
 	      g_string_append (str, clock);
@@ -181,7 +182,6 @@ greeter_item_is_visible (GreeterItemInfo *info)
   static gboolean checked = FALSE;
   static gboolean GDM_IS_LOCAL = FALSE;
   static gboolean GDM_FLEXI_SERVER = FALSE;
-  static gboolean GDM_TIMED_LOGIN_OK = FALSE;
 
   if ( ! checked)
     {
@@ -189,8 +189,6 @@ greeter_item_is_visible (GreeterItemInfo *info)
 	GDM_IS_LOCAL = TRUE;
       if (g_getenv ("GDM_FLEXI_SERVER") != NULL)
 	GDM_FLEXI_SERVER = TRUE;
-      if (g_getenv ("GDM_TIMED_LOGIN_OK") != NULL)
-	GDM_TIMED_LOGIN_OK = TRUE;
     }
 
   if (GDM_IS_LOCAL && ! GDM_FLEXI_SERVER &&
@@ -229,7 +227,7 @@ greeter_item_is_visible (GreeterItemInfo *info)
       strcmp (info->show_subtype, "suspend") == 0)
 	  return FALSE;
 
-  if ( ! GDM_TIMED_LOGIN_OK &&
+  if (ve_string_empty (GdmTimedLogin) &&
       info->show_type != NULL &&
       strcmp (info->show_type, "timed") == 0)
 	  return FALSE;
