@@ -256,3 +256,45 @@ ve_find_file (const char *filename, const GList *directories)
 
 	return NULL;
 }
+
+char *
+ve_locale_to_utf8 (const char *str)
+{
+	char *ret = g_locale_to_utf8 (str, -1, NULL, NULL, NULL);
+	if (ret == NULL) {
+		g_warning ("string not in proper locale encoding: \"%s\"", str);
+		return g_strdup (str);
+	} else {
+		return ret;
+	}
+}
+
+char *
+ve_locale_from_utf8 (const char *str)
+{
+	char *ret = g_locale_from_utf8 (str, -1, NULL, NULL, NULL);
+	if (ret == NULL) {
+		g_warning ("string not in proper utf8 encoding: \"%s\"", str);
+		return g_strdup (str);
+	} else {
+		return ret;
+	}
+}
+
+char *
+ve_strftime (struct tm *the_tm, const char *format)
+{
+	char str[1024];
+	char *loc_format = ve_locale_from_utf8 (format);
+
+	if (strftime (str, sizeof (str)-1, loc_format, the_tm) == 0) {
+		/* according to docs, if the string does not fit, the
+		 * contents of str are undefined, thus just use
+		 * ??? */
+		strcpy (str, "???");
+	}
+	str [sizeof (str)-1] = '\0'; /* just for sanity */
+	g_free (loc_format);
+
+	return ve_locale_to_utf8 (str);
+}
